@@ -20,7 +20,7 @@
 #ifndef __GCONF_TREE_MODEL_H__
 #define __GCONF_TREE_MODEL_H__
 
-#include <gtk/gtktreemodel.h>
+#include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 
 #define GCONF_TYPE_TREE_MODEL		  (gconf_tree_model_get_type ())
